@@ -131,7 +131,7 @@ List ProbabilityMatrixHorizontalDynamic(NumericMatrix vMat, int d, bool narm,
             
             if(b < xMat.ncol() - d){
 
-              if((Values(i) == xMat(a,b)) && (Values(j) == xMat(a, b+d))){
+              if(Values(i) == xMat(a,b) && Values(j) == xMat(a, b+d)){
                 out(i,j) += 1;
 
               }
