@@ -132,25 +132,25 @@ List ProbabilityMatrixAllDynamic(NumericMatrix vMat, int d, bool narm,
         for(int b = 0; b < xMat.ncol(); b++){
 
           if(b < xMat.ncol() - d){
-            if((Values(i) == xMat(a,b)) && (Values(j) == xMat(a, b+d))){
+            if(Values(i) == xMat(a,b) && Values(j) == xMat(a, b+d)){
               out(i,j) += 1;
             }
           }
 
-          if( (b >= d) & (a < xMat.nrow() - d) ){
-            if((Values(i) == xMat(a,b)) && (Values(j) == xMat(a+d, b-d))){
+          if( (b >= d) && (a < xMat.nrow() - d) ){
+            if(Values(i) == xMat(a,b) && Values(j) == xMat(a+d, b-d)){
               out(i,j) += 1;
             }
           }
 
           if(a < xMat.nrow() - d){
-            if((Values(i) == xMat(a,b)) && (Values(j) == xMat(a+d, b))){
+            if(Values(i) == xMat(a,b) && Values(j) == xMat(a+d, b)){
               out(i,j) += 1;
             }
           }
 
           if( (b < xMat.ncol() - d) && (a < xMat.nrow() - d) ){
-            if((Values(i) == xMat(a,b)) && (Values(j) == xMat(a+d, b+d))){
+            if(Values(i) == xMat(a,b) && Values(j) == xMat(a+d, b+d)){
               out(i,j) += 1;
             }
           }
